import { APIBrawler, APIMap, APIPowerPlayLeague, Country } from "../_interfaces/interfaces";
import BattleLog from "./BattleLog";
import Club, { Member } from "./Club";
import ClubRanking from "./ClubRanking";
import Player from "./Player";
import PlayerRanking from "./PlayerRanking";
/**
 * Class that represents a client for the Brawl Stars API
 * @class
 */
export default class Client {
    /**
     * The instance of the BrawlStarsApi class.
     * @type {API}
     * @private
     */
    private api;
    /**
     * Creates a new instance of the Client class.
     * @param {string} token The API token.
     * @constructor
     */
    constructor(token: string);
    /**
     * Retrieves a player's data from the Brawl Stars API.
     * @param {string} tag The player's tag, formatted as "#2R20PL0UR"
     * @returns {Promise<Player>} A promise that resolves to the player's data.
     */
    player(tag: string): Promise<Player>;
    /**
     * Retrieves the battle log for the player with the given tag.
     * @param {string} tag - The tag of the player to retrieve the battle log for.
     * @return {Promise<BattleLog>} A promise that resolves to an array of objects representing the player's battle log.
     */
    battleLog(tag: string): Promise<BattleLog>;
    /**
     * Returns information about a specific club.
     * @param {string} tag - Club tag
     * @returns {Promise<IClub>} Club information
     */
    club(tag: string): Promise<Club>;
    /**
     * Retrieves the list of members of a club.
     * @param {string} tag - The tag of the club to retrieve information for.
     * @returns {Promise<Member[]>} An array of objects representing the members of the club.
     */
    clubMembers(tag: string): Promise<Member[]>;
    /**
     * Returns a list of all brawlers in the game.
     * @returns {Promise<APIBrawler[]>} A promise that resolves to an array of brawlers.
     */
    brawlers(): Promise<APIBrawler[]>;
    /**
     * Retrieve information about a specific brawler
     * @param {number} id - The id brawler
     * @returns {Promise<APIBrawler>} A promise that resolves to an object containing information about the brawler
     */
    brawler(id: number | string): Promise<APIBrawler>;
    /**
     * Returns an array of seasons for the specified country's Power Play ranking.
     * @param {Country} [counrty="global"] - counrty The country to get the Power Play ranking seasons for. Defaults to 'global'.
     * @returns {Promise<APIPowerPlayLeague[]>} An array of seasons for the specified country's Power Play ranking.
     */
    powerPlayRankingSeasons(counrty?: Country): Promise<APIPowerPlayLeague[]>;
    /**
     * Get the trophy ranking for a specific country.
     * @param {Country} [counrty="global"] - counrty The country to get the ranking for. Defaults to "global".
     * @returns {Promise<IRankingPlayer[]>} An array of players ranked by their trophies.
     */
    trophyRanking(counrty?: Country): Promise<PlayerRanking>;
    /**
     * Get the power play ranking for a specific country and season.
     * @param {(number | "latest")} id The ID of the season. Defaults to "latest".
     * @param {Country} [counrty="global"] - counrty The country to get the ranking for. Defaults to "global".
     * @returns {Promise<IRankingPlayer[]>} An array of players ranked by their power play points.
     */
    powerPlayRanking(id?: string | number, counrty?: Country): Promise<PlayerRanking>;
    /**
     * @param {number | string} id - The brawler ID or name.
     * @param {Country} [counrty="global"] - The country code.
     * @returns {Promise<PlayerRanking>} A promise that resolves with the player ranking object.
     */
    brawlerRanking(id: string | number, counrty?: Country): Promise<PlayerRanking>;
    /**
     * Returns the club ranking for the specified country.
     * @param {Country} [counrty="global"] The country to get the ranking for.
     * @returns {Promise<ClubRanking>} A promise that resolves to the club ranking.
     */
    clubRanking(counrty?: Country): Promise<ClubRanking>;
    /**
     * Returns the current rotation of maps in the game.
     * @returns {Promise<APIMap>} The current rotation of maps.
     */
    rotation(): Promise<APIMap>;
}
